==> thunder-6.2.2.tar.gz: thunder/README.md <==
# <img src="./files/images/thunder.svg?sanitize=true" alt="Thunder" width="4%"/> Thunder [![Tweet](https://img.shields.io/twitter/url/http/shields.io.svg?style=social)](https://twitter.com/intent/tweet?text=I%20just%20tried%20ThunderCMS.%20The%20CMS%20for%20professional%20publishing!&url=https://www.thunder.org&via=ThunderCoreTeam&hashtags=drupal8,publishing,ThunderCMS)

[![Build Status](https://github.com/thunder/thunder-distribution/workflows/.github/workflows/test.yml/badge.svg)](https://github.com/thunder/thunder-distribution/actions)

Thunder is a Drupal distribution for professional publishers. It consists of the current Drupal functionality, lots of
useful modules from publishers and industry partners, and an environment which makes it easy to install, deploy and add
new functionality.

## Installing Thunder

Instructions on how to install Thunder can be found at
the [installation guide](https://thunder.github.io/developer-guide/setup.html#install-thunder).

### Updating Thunder 3 to Thunder 6

If you want to update from Thunder 3 to Thunder 6 some manual steps are necessary, they are described here:

[How to update Thunder 3 to Thunder 6](https://thunder.github.io/developer-guide/migration/migrate-3-6.html)

## Feature Highlights

### <img src="./files/images/story_fireplace_b.png" alt="Storytelling" width="2%"/> Storytelling

Create thrilling articles with multimedia content. It’s easy to enrich your article with pictures, video, and social
media snippets and arrange everything as you like it.

![Storytelling](./files/images/storytelling.png)

### <img src="./files/images/media_handling_b_0.png" alt="Storytelling" width="2%"/> Media handling

Add pictures, galleries and videos to your article by just dragging and dropping everything right where you need it.

### <img src="./files/images/mobile_friendly_e_0.png" alt="Storytelling" width="2%"/> Mobile friendly

With Thunder, editors and administrators can work from any device – on the go, easy and fast. Users benefit from a
modern and flexible front end.

![Mobile preview](./files/images/mobile.png)

### <img src="./files/images/schedule_content_g_0.png" alt="Storytelling" width="2%"/> Schedule content

Plan at which day and time articles should be published – and when they shouldn’t be visible to the public anymore.

### <img src="./files/images/flexible_system_b_0.png" alt="Storytelling" width="2%"/> Flexible system

Benefit from a wide range of additional functionality by industry partners or by one of more than 2,500 modules from the
Drupal community.

### <img src="./files/images/drupal_community_b_1.png" alt="Storytelling" width="2%"/> Open Source

Using open source technology reduces development costs and resources and makes you part of the Drupal community with
more than 100,000 users actively contributing.

*[More information about the modules used in Thunder](https://thunder.github.io/user-guide/feature-overview.html)*

## Support

For general help using Thunder, please refer to [the official Thunder documentation](https://thunder.github.io).

### Community support

For additional help, you can use one of this channel to ask question:

* [Slack](https://thunder.org/contact-us) (highly recommended for faster support)
* [Twitter](https://twitter.com/ThunderCoreTeam)
* [Facebook](https://www.facebook.com/Thunder-CMS-168018513979183/).

## Contributing

If you want to help, to make Thunder even better, please take a look at the [contributing guidelines](CONTRIBUTING.md).

## Development

For information on the installation and development of Thunder, please take a look
at [docs/developer-guide](docs/developer-guide).

==> thunder-7.3.5.tar.gz: thunder/README.md <==
# <img src="./files/images/thunder.svg?sanitize=true" alt="Thunder" width="4%"/> Thunder [![Tweet](https://img.shields.io/twitter/url/http/shields.io.svg?style=social)](https://twitter.com/intent/tweet?text=I%20just%20tried%20ThunderCMS.%20The%20CMS%20for%20professional%20publishing!&url=https://www.thunder.org&via=ThunderCoreTeam&hashtags=drupal8,publishing,ThunderCMS)

[![Build Status](https://github.com/thunder/thunder-distribution/workflows/.github/workflows/test.yml/badge.svg)](https://github.com/thunder/thunder-distribution/actions)

Thunder is a Drupal distribution for professional publishers. It consists of the current Drupal functionality, lots of
useful modules from publishers and industry partners, and an environment which makes it easy to install, deploy and add
new functionality.

## Installing Thunder

Instructions on how to install Thunder can be found at
the [installation guide](https://thunder.github.io/developer-guide/setup.html#install-thunder).

### Updating Thunder 3 to Thunder 6

If you want to update from Thunder 3 to Thunder 6 some manual steps are necessary, they are described here:

[How to update Thunder 3 to Thunder 6](https://thunder.github.io/developer-guide/migration/migrate-3-6.html)

## Feature Highlights

### <img src="./files/images/story_fireplace_b.png" alt="Storytelling" width="2%"/> Storytelling

Create thrilling articles with multimedia content. It’s easy to enrich your article with pictures, video, and social
media snippets and arrange everything as you like it.

![Storytelling](./files/images/storytelling.png)

### <img src="./files/images/media_handling_b_0.png" alt="Storytelling" width="2%"/> Media handling

Add pictures, galleries and videos to your article by just dragging and dropping everything right where you need it.

### <img src="./files/images/mobile_friendly_e_0.png" alt="Storytelling" width="2%"/> Mobile friendly

With Thunder, editors and administrators can work from any device – on the go, easy and fast. Users benefit from a
modern and flexible front end.

![Mobile preview](./files/images/mobile.png)

### <img src="./files/images/schedule_content_g_0.png" alt="Storytelling" width="2%"/> Schedule content

Plan at which day and time articles should be published – and when they shouldn’t be visible to the public anymore.

### <img src="./files/images/flexible_system_b_0.png" alt="Storytelling" width="2%"/> Flexible system

Benefit from a wide range of additional functionality by industry partners or by one of more than 2,500 modules from the
Drupal community.

### <img src="./files/images/drupal_community_b_1.png" alt="Storytelling" width="2%"/> Open Source

Using open source technology reduces development costs and resources and makes you part of the Drupal community with
more than 100,000 users actively contributing.

*[More information about the modules used in Thunder](https://thunder.github.io/user-guide/feature-overview.html)*

## Support

For general help using Thunder, please refer to [the official Thunder documentation](https://thunder.github.io).

### Community support

For additional help, you can use one of these channels to ask question:

* [Slack](https://thunder.org/contact-us) (highly recommended for faster support)
* [Twitter](https://twitter.com/ThunderCoreTeam)
* [Facebook](https://www.facebook.com/Thunder-CMS-168018513979183/).

## Contributing

If you want to help, to make Thunder even better, please take a look at the [contributing guidelines](docs/contributing.md).

## Development

For information on the installation and development of Thunder, please take a look
at [docs/developer-guide](docs/developer-guide).
